stravalib.client.ActivityUploader
=================================

.. currentmodule:: stravalib.client

.. autoclass:: ActivityUploader


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~ActivityUploader.__init__
      ~ActivityUploader.poll
      ~ActivityUploader.raise_for_error
      ~ActivityUploader.update_from_response
      ~ActivityUploader.upload_photo
      ~ActivityUploader.wait





   .. rubric:: Attributes

   .. autosummary::

      ~ActivityUploader.is_complete
      ~ActivityUploader.is_error
      ~ActivityUploader.is_processing
      ~ActivityUploader.photo_metadata
